summaryrefslogtreecommitdiffstatshomepage
path: root/src/osd/mac/video.cpp
diff options
context:
space:
mode:
Diffstat (limited to 'src/osd/mac/video.cpp')
-rw-r--r--src/osd/mac/video.cpp4
1 files changed, 2 insertions, 2 deletions
diff --git a/src/osd/mac/video.cpp b/src/osd/mac/video.cpp
index e5feba57f76..1dab5f5782e 100644
--- a/src/osd/mac/video.cpp
+++ b/src/osd/mac/video.cpp
@@ -136,8 +136,8 @@ void mac_osd_interface::input_update(bool relative_reset)
void mac_osd_interface::check_osd_inputs()
{
- // check for toggling fullscreen mode
- if (machine().ui_input().pressed(IPT_OSD_1))
+ // check for toggling fullscreen mode (don't do this in debug mode)
+ if (machine().ui_input().pressed(IPT_OSD_1) && !(machine().debug_flags & DEBUG_FLAG_OSD_ENABLED))
{
// destroy the renderers first so that the render module can bounce if it depends on having a window handle
for (auto it = window_list().rbegin(); window_list().rend() != it; ++it)